window.Gleam.initSearch([{"doc":"glitr_wisp","title":"glitr_wisp","content":"# glitr_wisp\n\nInterface for wisp to use Glitr&#39;s typed routes\n\n[![Package Version](https://img.shields.io/hexpm/v/glitr_wisp)](https://hex.pm/packages/glitr_wisp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glitr_wisp/)\n\n```sh\ngleam add glitr_wisp\n```\n```gleam\nimport glitr_wisp\nimport wisp.{type Request, type Response}\n\npub fn handle_request(req: Request, ctx: web.Context) -&gt; Response {\n  use _req &lt;- web.middleware(req)\n\n  glitr_wisp.for(req)\n  |&gt; glitr_wisp.try(todo_routes.get_all(), todo_service.get_all(ctx, _))\n  |&gt; glitr_wisp.try(todo_routes.get(), todo_service.get(ctx, _))\n  |&gt; glitr_wisp.try(todo_routes.create(), todo_service.create(ctx, _))\n  |&gt; glitr_wisp.try(todo_routes.update(), todo_service.update(ctx, _))\n  |&gt; glitr_wisp.try(todo_routes.delete(), todo_service.delete(ctx, _))\n  |&gt; glitr_wisp.unwrap\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glitr_wisp&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glitr/wisp/errors","title":"AppError","content":"pub type AppError {\n  DBError(message: String)\n  DecoderError(message: String)\n  InternalError(message: String)\n}\n Errors that may happen when using glitr_wisp\nDBError(message: String)\n\n\nDecoderError(message: String)\n\n\nInternalError(message: String)\n\n\nSynonyms:\nglitr/wisp/errors.AppError\nglitr/wisp/errors AppError","url":"glitr/wisp/errors.html#AppError"},{"doc":"glitr/wisp/errors","title":"glitr/wisp/errors","content":"","url":"glitr/wisp/errors.html"},{"doc":"glitr/wisp","title":"Router","content":"pub opaque type Router\n A Router is basically a request handler for glitr Routes  \n It store the incoming request and will compare it to the different Routes that are provided to it.\n The resulting response is generated based on the matching Route and the handler associated to it.\n\nSynonyms:\nglitr/wisp.Router\nglitr/wisp Router","url":"glitr/wisp.html#Router"},{"doc":"glitr/wisp","title":"for","content":"pub fn for(\n  req: Request(Connection),\n) -&gt; Result(Router, Response(Body))\n Create a new Router for the incoming request\nSynonyms:\nglitr/wisp.for\nglitr/wisp for","url":"glitr/wisp.html#for"},{"doc":"glitr/wisp","title":"try","content":"pub fn try(\n  router_res: Result(Router, Response(Body)),\n  route: Route(a, b, c, d),\n  handler: fn(RouteOptions(a, b, c)) -&gt; Result(d, AppError),\n) -&gt; Result(Router, Response(Body))\n Compare the stored request with the provided Route  \n If the first parameter has a response, this will be ignored.\n Otherwise, if the request match the Route, generate a response based on the provided handler,\n else return the Router so that these functions can be chained.\nSynonyms:\nglitr/wisp.try\nglitr/wisp try","url":"glitr/wisp.html#try"},{"doc":"glitr/wisp","title":"try_map","content":"pub fn try_map(\n  router_res: Result(Router, Response(Body)),\n  route: Route(a, b, c, d),\n  handler: fn(RouteOptions(a, b, c)) -&gt; Result(d, AppError),\n  map_fn: fn(Response(Body)) -&gt; Response(Body),\n) -&gt; Result(Router, Response(Body))\n Do the same as the try function but also map the generated response\nSynonyms:\nglitr/wisp.try_map\nglitr/wisp try_map","url":"glitr/wisp.html#try_map"},{"doc":"glitr/wisp","title":"try_map_service_route","content":"pub fn try_map_service_route(\n  router_res: Result(Router, Response(Body)),\n  route: Result(Route(a, b, c, d), GlitrError),\n  handler: fn(RouteOptions(a, b, c)) -&gt; Result(d, AppError),\n  map_fn: fn(Response(Body)) -&gt; Response(Body),\n) -&gt; Result(Router, Response(Body))\n Do the same as try_map, but take a Result(Route, GlitrError) as a parameter  \n If the route is an Error, a log is printed and the route is ignored\nSynonyms:\nglitr/wisp.try_map_service_route\nglitr/wisp try_map_service_route","url":"glitr/wisp.html#try_map_service_route"},{"doc":"glitr/wisp","title":"try_service_route","content":"pub fn try_service_route(\n  router_res: Result(Router, Response(Body)),\n  route: Result(Route(a, b, c, d), GlitrError),\n  handler: fn(RouteOptions(a, b, c)) -&gt; Result(d, AppError),\n) -&gt; Result(Router, Response(Body))\n Do the same as try, but take a Result(Route, GlitrError) as a parameter  \n If the route is an Error, a log is printed and the route is ignored\nSynonyms:\nglitr/wisp.try_service_route\nglitr/wisp try_service_route","url":"glitr/wisp.html#try_service_route"},{"doc":"glitr/wisp","title":"unwrap","content":"pub fn unwrap(\n  router_res: Result(Router, Response(Body)),\n) -&gt; Response(Body)\n Unwrap the response generated by a Route or return a not_found if no route matched\nSynonyms:\nglitr/wisp.unwrap\nglitr/wisp unwrap","url":"glitr/wisp.html#unwrap"},{"doc":"glitr/wisp","title":"glitr/wisp","content":"","url":"glitr/wisp.html"},{"doc":"glitr_wisp","title":"glitr_wisp","content":"","url":"glitr_wisp.html"}]);